@@ -690,7 +690,7 @@ def run_tool_sim_hydrology_8(DEM=None, FLOW_K=None, FLOW_ACC=None, FLOW=None, TI
         return Tool.Execute(Verbose)
     return False
 
-def Overland_Flow(DEM=None, ROUGHNESS=None, INTER_MAX=None, POND_MAX=None, INFIL_MAX=None, FLOW=None, PRECIP=None, ET_POT=None, INTERCEPT=None, PONDING=None, INFILTRAT=None, VELOCITY=None, SUMMARY=None, ROUGHNESS_DEFAULT=None, STRICKLER=None, INTER_MAX_DEFAULT=None, POND_MAX_DEFAULT=None, INFIL_MAX_DEFAULT=None, WEATHER=None, PRECIP_DEFAULT=None, ET_POT_DEFAULT=None, RESET=None, TIME_STOP=None, TIME_STEP=None, FLOW_OUT=None, TIME_UPDATE=None, UPDATE_FLOW_FIXED=None, UPDATE_FLOW_RANGE=None, UPDATE_VELO_FIXED=None, UPDATE_VELO_RANGE=None, Verbose=2):
+def Overland_Flow(DEM=None, ROUGHNESS=None, INTER_MAX=None, POND_MAX=None, INFIL_MAX=None, FLOW=None, PRECIP=None, ET_POT=None, MONITOR_POINTS=None, INTERCEPT=None, PONDING=None, INFILTRAT=None, VELOCITY=None, SUMMARY=None, MONITOR_SERIES=None, ROUGHNESS_DEFAULT=None, STRICKLER=None, INTER_MAX_DEFAULT=None, POND_MAX_DEFAULT=None, INFIL_MAX_DEFAULT=None, WEATHER=None, PRECIP_DEFAULT=None, ET_POT_DEFAULT=None, RESET=None, TIME_STOP=None, TIME_STEP=None, FLOW_OUT=None, TIME_UPDATE=None, UPDATE_FLOW_FIXED=None, UPDATE_FLOW_RANGE=None, UPDATE_VELO_FIXED=None, UPDATE_VELO_RANGE=None, MONITOR_NAME=None, MONITOR_UPDATE=None, MONITOR_RESET=None, Verbose=2):
     '''
     Overland Flow
     ----------
@@ -706,11 +706,13 @@ def Overland_Flow(DEM=None, ROUGHNESS=None, INTER_MAX=None, POND_MAX=None, INFIL
     - FLOW [`optional input grid`] : Flow [mm]
     - PRECIP [`optional input grid`] : Precipitation [mm/h]
     - ET_POT [`optional input grid`] : Potential Evapotranspiration [mm/h]
+    - MONITOR_POINTS [`optional input shapes`] : Monitors
     - INTERCEPT [`output grid`] : Interception [mm]
     - PONDING [`output grid`] : Ponding [mm]
     - INFILTRAT [`output grid`] : Infiltration [mm]
     - VELOCITY [`output grid`] : Velocity [m/h]
     - SUMMARY [`output table`] : Overland Flow Summary
+    - MONITOR_SERIES [`output table`] : Time Series. Flow accumulation values collected for each monitor point.
     - ROUGHNESS_DEFAULT [`floating point number`] : Default. Minimum: 0.000000 Default: 20.000000 default value if no grid has been selected
     - STRICKLER [`choice`] : Type. Available Choices: [0] Strickler Ks, [m^1/3 / s] [1] Gauckler-Manning n, [s / m^1/3] Default: 0 Ks Strickler = 1/n Gauckler-Manning
     - INTER_MAX_DEFAULT [`floating point number`] : Default. Minimum: 0.000000 Default: 0.000000 default value if no grid has been selected
@@ -723,11 +725,14 @@ def Overland_Flow(DEM=None, ROUGHNESS=None, INTER_MAX=None, POND_MAX=None, INFIL
     - TIME_STOP [`floating point number`] : Simulation Time [h]. Minimum: 0.000000 Default: 6.000000 Simulation time in hours.
     - TIME_STEP [`floating point number`] : Time Step Adjustment. Minimum: 0.010000 Maximum: 1.000000 Default: 0.500000 Choosing a lower value will result in a better numerical precision but also in a longer calculation time.
     - FLOW_OUT [`boolean`] : Overland Flow Summary. Default: 0 Report the amount of overland flow that left the covered area.
-    - TIME_UPDATE [`floating point number`] : Map Update Frequency [Minutes]. Minimum: 0.000000 Default: 1.000000 Map update frequency in minutes. Set to zero to update each simulation time step.
+    - TIME_UPDATE [`floating point number`] : Map Update Frequency. Minimum: 0.000000 Default: 1.000000 Map update frequency in minutes. Set to zero to update each simulation time step.
     - UPDATE_FLOW_FIXED [`boolean`] : Fixed Color Stretch for Flow. Default: 0
     - UPDATE_FLOW_RANGE [`value range`] : Fixed Color Stretch
     - UPDATE_VELO_FIXED [`boolean`] : Fixed Color Stretch for Velocity. Default: 1
     - UPDATE_VELO_RANGE [`value range`] : Fixed Color Stretch
+    - MONITOR_NAME [`table field`] : Name. Used to name time series fields. Will simply be enumerated if not set.
+    - MONITOR_UPDATE [`floating point number`] : Monitor Update Frequency. Minimum: 0.000000 Default: 1.000000 Monitor update frequency in minutes. Set to zero to update each simulation time step.
+    - MONITOR_RESET [`boolean`] : Reset. Default: 0
 
     - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
     Returns
@@ -744,11 +749,13 @@ def Overland_Flow(DEM=None, ROUGHNESS=None, INTER_MAX=None, POND_MAX=None, INFIL
         Tool.Set_Input ('FLOW', FLOW)
         Tool.Set_Input ('PRECIP', PRECIP)
         Tool.Set_Input ('ET_POT', ET_POT)
+        Tool.Set_Input ('MONITOR_POINTS', MONITOR_POINTS)
         Tool.Set_Output('INTERCEPT', INTERCEPT)
         Tool.Set_Output('PONDING', PONDING)
         Tool.Set_Output('INFILTRAT', INFILTRAT)
         Tool.Set_Output('VELOCITY', VELOCITY)
         Tool.Set_Output('SUMMARY', SUMMARY)
+        Tool.Set_Output('MONITOR_SERIES', MONITOR_SERIES)
         Tool.Set_Option('ROUGHNESS_DEFAULT', ROUGHNESS_DEFAULT)
         Tool.Set_Option('STRICKLER', STRICKLER)
         Tool.Set_Option('INTER_MAX_DEFAULT', INTER_MAX_DEFAULT)
@@ -766,10 +773,13 @@ def Overland_Flow(DEM=None, ROUGHNESS=None, INTER_MAX=None, POND_MAX=None, INFIL
         Tool.Set_Option('UPDATE_FLOW_RANGE', UPDATE_FLOW_RANGE)
         Tool.Set_Option('UPDATE_VELO_FIXED', UPDATE_VELO_FIXED)
         Tool.Set_Option('UPDATE_VELO_RANGE', UPDATE_VELO_RANGE)
+        Tool.Set_Option('MONITOR_NAME', MONITOR_NAME)
+        Tool.Set_Option('MONITOR_UPDATE', MONITOR_UPDATE)
+        Tool.Set_Option('MONITOR_RESET', MONITOR_RESET)
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_sim_hydrology_9(DEM=None, ROUGHNESS=None, INTER_MAX=None, POND_MAX=None, INFIL_MAX=None, FLOW=None, PRECIP=None, ET_POT=None, INTERCEPT=None, PONDING=None, INFILTRAT=None, VELOCITY=None, SUMMARY=None, ROUGHNESS_DEFAULT=None, STRICKLER=None, INTER_MAX_DEFAULT=None, POND_MAX_DEFAULT=None, INFIL_MAX_DEFAULT=None, WEATHER=None, PRECIP_DEFAULT=None, ET_POT_DEFAULT=None, RESET=None, TIME_STOP=None, TIME_STEP=None, FLOW_OUT=None, TIME_UPDATE=None, UPDATE_FLOW_FIXED=None, UPDATE_FLOW_RANGE=None, UPDATE_VELO_FIXED=None, UPDATE_VELO_RANGE=None, Verbose=2):
+def run_tool_sim_hydrology_9(DEM=None, ROUGHNESS=None, INTER_MAX=None, POND_MAX=None, INFIL_MAX=None, FLOW=None, PRECIP=None, ET_POT=None, MONITOR_POINTS=None, INTERCEPT=None, PONDING=None, INFILTRAT=None, VELOCITY=None, SUMMARY=None, MONITOR_SERIES=None, ROUGHNESS_DEFAULT=None, STRICKLER=None, INTER_MAX_DEFAULT=None, POND_MAX_DEFAULT=None, INFIL_MAX_DEFAULT=None, WEATHER=None, PRECIP_DEFAULT=None, ET_POT_DEFAULT=None, RESET=None, TIME_STOP=None, TIME_STEP=None, FLOW_OUT=None, TIME_UPDATE=None, UPDATE_FLOW_FIXED=None, UPDATE_FLOW_RANGE=None, UPDATE_VELO_FIXED=None, UPDATE_VELO_RANGE=None, MONITOR_NAME=None, MONITOR_UPDATE=None, MONITOR_RESET=None, Verbose=2):
     '''
     Overland Flow
     ----------
@@ -785,11 +795,13 @@ def run_tool_sim_hydrology_9(DEM=None, ROUGHNESS=None, INTER_MAX=None, POND_MAX=
     - FLOW [`optional input grid`] : Flow [mm]
     - PRECIP [`optional input grid`] : Precipitation [mm/h]
     - ET_POT [`optional input grid`] : Potential Evapotranspiration [mm/h]
+    - MONITOR_POINTS [`optional input shapes`] : Monitors
     - INTERCEPT [`output grid`] : Interception [mm]
     - PONDING [`output grid`] : Ponding [mm]
     - INFILTRAT [`output grid`] : Infiltration [mm]
     - VELOCITY [`output grid`] : Velocity [m/h]
     - SUMMARY [`output table`] : Overland Flow Summary
+    - MONITOR_SERIES [`output table`] : Time Series. Flow accumulation values collected for each monitor point.
     - ROUGHNESS_DEFAULT [`floating point number`] : Default. Minimum: 0.000000 Default: 20.000000 default value if no grid has been selected
     - STRICKLER [`choice`] : Type. Available Choices: [0] Strickler Ks, [m^1/3 / s] [1] Gauckler-Manning n, [s / m^1/3] Default: 0 Ks Strickler = 1/n Gauckler-Manning
     - INTER_MAX_DEFAULT [`floating point number`] : Default. Minimum: 0.000000 Default: 0.000000 default value if no grid has been selected
@@ -802,11 +814,14 @@ def run_tool_sim_hydrology_9(DEM=None, ROUGHNESS=None, INTER_MAX=None, POND_MAX=
     - TIME_STOP [`floating point number`] : Simulation Time [h]. Minimum: 0.000000 Default: 6.000000 Simulation time in hours.
     - TIME_STEP [`floating point number`] : Time Step Adjustment. Minimum: 0.010000 Maximum: 1.000000 Default: 0.500000 Choosing a lower value will result in a better numerical precision but also in a longer calculation time.
     - FLOW_OUT [`boolean`] : Overland Flow Summary. Default: 0 Report the amount of overland flow that left the covered area.
-    - TIME_UPDATE [`floating point number`] : Map Update Frequency [Minutes]. Minimum: 0.000000 Default: 1.000000 Map update frequency in minutes. Set to zero to update each simulation time step.
+    - TIME_UPDATE [`floating point number`] : Map Update Frequency. Minimum: 0.000000 Default: 1.000000 Map update frequency in minutes. Set to zero to update each simulation time step.
     - UPDATE_FLOW_FIXED [`boolean`] : Fixed Color Stretch for Flow. Default: 0
     - UPDATE_FLOW_RANGE [`value range`] : Fixed Color Stretch
     - UPDATE_VELO_FIXED [`boolean`] : Fixed Color Stretch for Velocity. Default: 1
     - UPDATE_VELO_RANGE [`value range`] : Fixed Color Stretch
+    - MONITOR_NAME [`table field`] : Name. Used to name time series fields. Will simply be enumerated if not set.
+    - MONITOR_UPDATE [`floating point number`] : Monitor Update Frequency. Minimum: 0.000000 Default: 1.000000 Monitor update frequency in minutes. Set to zero to update each simulation time step.
+    - MONITOR_RESET [`boolean`] : Reset. Default: 0
 
     - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
     Returns
@@ -823,11 +838,13 @@ def run_tool_sim_hydrology_9(DEM=None, ROUGHNESS=None, INTER_MAX=None, POND_MAX=
         Tool.Set_Input ('FLOW', FLOW)
         Tool.Set_Input ('PRECIP', PRECIP)
         Tool.Set_Input ('ET_POT', ET_POT)
+        Tool.Set_Input ('MONITOR_POINTS', MONITOR_POINTS)
         Tool.Set_Output('INTERCEPT', INTERCEPT)
         Tool.Set_Output('PONDING', PONDING)
         Tool.Set_Output('INFILTRAT', INFILTRAT)
         Tool.Set_Output('VELOCITY', VELOCITY)
         Tool.Set_Output('SUMMARY', SUMMARY)
+        Tool.Set_Output('MONITOR_SERIES', MONITOR_SERIES)
         Tool.Set_Option('ROUGHNESS_DEFAULT', ROUGHNESS_DEFAULT)
         Tool.Set_Option('STRICKLER', STRICKLER)
         Tool.Set_Option('INTER_MAX_DEFAULT', INTER_MAX_DEFAULT)
@@ -845,6 +862,9 @@ def run_tool_sim_hydrology_9(DEM=None, ROUGHNESS=None, INTER_MAX=None, POND_MAX=
         Tool.Set_Option('UPDATE_FLOW_RANGE', UPDATE_FLOW_RANGE)
         Tool.Set_Option('UPDATE_VELO_FIXED', UPDATE_VELO_FIXED)
         Tool.Set_Option('UPDATE_VELO_RANGE', UPDATE_VELO_RANGE)
+        Tool.Set_Option('MONITOR_NAME', MONITOR_NAME)
+        Tool.Set_Option('MONITOR_UPDATE', MONITOR_UPDATE)
+        Tool.Set_Option('MONITOR_RESET', MONITOR_RESET)
         return Tool.Execute(Verbose)
     return False
 
@@ -969,7 +989,7 @@ def Soil_Water_Simulation_after_Glugla_Grid(P=None, ETP=None, FC=None, PWP=None,
     - ETP [`input grid list`] : Potential Evapotranspiration. [mm]
     - FC [`optional input grid list`] : Field Capacity. [vol.%]
     - PWP [`optional input grid list`] : Permanent Wilting Point. [vol.%]
-    - ETMAX [`optional input grid list`] : Maxmimum Evapotranspiration. [vol.%/day]
+    - ETMAX [`optional input grid list`] : Maximum Evapotranspiration. [vol.%/day]
     - LAI [`optional input grid`] : Leaf Area Index
     - GLUGLA [`optional input grid`] : Glugla Coefficient. Empirical parameter [mm/day], depends on soil texture and structure.
     - SOIL_WATER [`output grid list`] : Soil Water Content
@@ -1039,7 +1059,7 @@ def run_tool_sim_hydrology_11(P=None, ETP=None, FC=None, PWP=None, ETMAX=None, L
     - ETP [`input grid list`] : Potential Evapotranspiration. [mm]
     - FC [`optional input grid list`] : Field Capacity. [vol.%]
     - PWP [`optional input grid list`] : Permanent Wilting Point. [vol.%]
-    - ETMAX [`optional input grid list`] : Maxmimum Evapotranspiration. [vol.%/day]
+    - ETMAX [`optional input grid list`] : Maximum Evapotranspiration. [vol.%/day]
     - LAI [`optional input grid`] : Leaf Area Index
     - GLUGLA [`optional input grid`] : Glugla Coefficient. Empirical parameter [mm/day], depends on soil texture and structure.
     - SOIL_WATER [`output grid list`] : Soil Water Content
