@@ -153,7 +153,7 @@ bool CSG_Projection::Create(const CSG_String &Definition)
 {
 	Destroy();
 
-	if( CSG_Projections::Parse(Definition, NULL, &m_WKT2, &m_PROJ, NULL) )
+	if( CSG_Projections::Parse(Definition, &m_PROJ, &m_WKT2) )
 	{
 		CSG_MetaData WKT(CSG_Projections::_WKT2_to_MetaData(m_WKT2, true));
 
@@ -202,6 +202,35 @@ bool CSG_Projection::Create(int Code, const SG_Char *Authority)
 	return( Create(gSG_Projections.Get_Projection(Code, Authority)) ); // request SAGA's internal CRS database (might provide definitions not included in PROJ's default database)
 }
 
+//---------------------------------------------------------
+CSG_Projection::CSG_Projection(const CSG_String &WKT2, const CSG_String &PROJ)
+{
+	Create(WKT2, PROJ);
+}
+
+bool CSG_Projection::Create(const CSG_String &WKT2, const CSG_String &PROJ)
+{
+	if( PROJ.is_Empty() )
+	{
+		return( Create(WKT2) );
+	}
+
+	m_PROJ = PROJ;
+	m_WKT2 = WKT2;
+
+	CSG_MetaData WKT(CSG_Projections::_WKT2_to_MetaData(m_WKT2, true));
+
+	m_Type = CSG_Projections::Get_CRS_Type(WKT.Get_Name());
+	m_Name = WKT.Get_Property("NAME"); if( m_Name.is_Empty() ) { m_Name = "unnamed"; }
+
+	if( !WKT("ID") || !WKT["ID"].Get_Content("VAL1", m_Code) || !WKT["ID"].Get_Property("NAME", m_Authority) )
+	{
+		m_Authority.Clear(); m_Code = -1;
+	}
+
+	return( true );
+}
+
 //---------------------------------------------------------
 void CSG_Projection::Destroy(void)
 {
@@ -286,17 +315,19 @@ bool CSG_Projection::Save(CSG_File &Stream, ESG_CRS_Format Format)	const
 //---------------------------------------------------------
 bool CSG_Projection::Load(const CSG_MetaData &Projection)
 {
+	if( Projection("WKT2") && Projection("PROJ") && Create(Projection["WKT2"].Get_Content(), Projection["PROJ"].Get_Content()) ) { return( true ); }
+
 	if( Projection("WKT2") && Create(Projection["WKT2"].Get_Content()) ) { return( true ); }
-	if( Projection("WKT1") && Create(Projection["WKT1"].Get_Content()) ) { return( true ); }
 	if( Projection("PROJ") && Create(Projection["PROJ"].Get_Content()) ) { return( true ); }
 
 	//-----------------------------------------------------
-	// >>> backward compatibilty
+	// >>> backward compatibility
 
+	if( Projection("WKT1"   ) && Create(Projection["WKT1"   ].Get_Content()) ) { return( true ); }
 	if( Projection("OGC_WKT") && Create(Projection["OGC_WKT"].Get_Content()) ) { return( true ); }
 	if( Projection("PROJ4"  ) && Create(Projection["PROJ4"  ].Get_Content()) ) { return( true ); }
 
-	// <<< backward compatibilty
+	// <<< backward compatibility
 	//-----------------------------------------------------
 
 	return( false );
@@ -358,15 +389,11 @@ CSG_String CSG_Projection::Get_Description(bool bDetails) const
 
 	if( !bDetails )
 	{
-		CSG_String s;
+		CSG_String s(CSG_Projections::Get_CRS_Type_Name(m_Type));
 
-		if( !m_Name.is_Empty() && m_Name.CmpNoCase("unknown") )
+		if( !m_Name.is_Empty() && m_Name.CmpNoCase("<custom>") )
 		{
-			s = m_Name;
-		}
-		else
-		{
-			s.Printf("[%s]", _TL("user defined"));
+			s += "\n" + m_Name;
 		}
 
 		if( m_Code > 0 && !m_Authority.is_Empty() )
@@ -419,7 +446,7 @@ CSG_String CSG_Projection::Get_Description(bool bDetails) const
 
 		pGCS = PRJ("BASEGEODCRS");
 	}
-	else if( is_Geographic() )
+	else if( is_Geographic() || is_Geodetic() )
 	{
 		pGCS = WKT   .Cmp_Name("GEOGCRS") || WKT   .Cmp_Name("GEODCRS") ? &WKT
 		     : WKT[0].Cmp_Name("GEOGCRS") || WKT[0].Cmp_Name("GEODCRS") ? &WKT[0] : &WKT[0][0];
@@ -498,7 +525,7 @@ bool CSG_Projection::is_Equal(const CSG_Projection &Projection)	const
 
 	#define CMP_CONTENT(a, b    ) (a && b && a->Cmp_Content(b->Get_Content()))
 	#define CMP_PROPERTY(a, b, p) (a && b && a->Get_Property(p) && b->Cmp_Property(p, a->Get_Property(p), true))
-	#define CMP_PARAMETER(a, b  ) (a && b && ((!a->Cmp_Name("PARAMETER") && !b->Cmp_Name("PARAMETER")) || CMP_PROPERTY(a, b, "name") && a->Cmp_Content(b->Get_Content())))
+	#define CMP_PARAMETER(a, b  ) (a && b && ((!a->Cmp_Name("PARAMETER") && !b->Cmp_Name("PARAMETER")) || (CMP_PROPERTY(a, b, "name") && a->Cmp_Content(b->Get_Content()))))
 
 	CSG_MetaData WKT[2] = {
 		CSG_Projections::_WKT1_to_MetaData(           Get_WKT1()),
@@ -519,7 +546,7 @@ bool CSG_Projection::is_Equal(const CSG_Projection &Projection)	const
 		pGCS[0] = WKT[0]("GEOGCS");
 		pGCS[1] = WKT[1]("GEOGCS");
 	}
-	else if( is_Geographic() )
+	else if( is_Geographic() || is_Geodetic() )
 	{
 		pGCS[0] = &WKT[0];
 		pGCS[1] = &WKT[1];
@@ -614,7 +641,45 @@ const CSG_Projection & CSG_Projection::Get_GCS_WGS84(void)
 //---------------------------------------------------------
 bool CSG_Projection::Set_GCS_WGS84(void)
 {
-	return( Create(4326) );
+	m_Name      = "WGS 84";
+	m_Type      = ESG_CRS_Type::Geographic;
+	m_Unit      = ESG_Projection_Unit::Undefined;
+	m_Authority = "EPSG";
+	m_Code      = 4326;
+	m_PROJ      = "+proj=longlat +datum=WGS84 +no_defs";
+	m_WKT2      =
+		"GEODCRS[\"WGS 84\","
+		"    DATUM[\"World Geodetic System 1984\","
+		"        ELLIPSOID[\"WGS 84\",6378137,298.257223563]],"
+		"    CS[ellipsoidal,2],"
+		"        AXIS[\"geodetic latitude (Lat)\",north],"
+		"        AXIS[\"geodetic longitude (Lon)\",east],"
+		"        UNIT[\"degree\",0.0174532925199433],"
+		"    SCOPE[\"Horizontal component of 3D system.\"],"
+		"    AREA[\"World.\"],"
+		"    BBOX[-90,-180,90,180],"
+		"    ID[\"EPSG\",4326]]";
+
+//	m_WKT2      =
+//		"GEODCRS[\"WGS 84\","
+//		"    DATUM[\"World Geodetic System 1984\","
+//		"        ELLIPSOID[\"WGS 84\",6378137,298.257223563,"
+//		"            LENGTHUNIT[\"metre\",1]]],"
+//		"    PRIMEM[\"Greenwich\",0,"
+//		"        ANGLEUNIT[\"degree\",0.0174532925199433]],"
+//		"    CS[ellipsoidal,2],"
+//		"        AXIS[\"geodetic latitude (Lat)\",north,"
+//		"            ORDER[1],"
+//		"            ANGLEUNIT[\"degree\",0.0174532925199433]],"
+//		"        AXIS[\"geodetic longitude (Lon)\",east,"
+//		"            ORDER[2],"
+//		"            ANGLEUNIT[\"degree\",0.0174532925199433]],"
+//		"    SCOPE[\"Horizontal component of 3D system.\"],"
+//		"   AREA[\"World.\"],"
+//		"    BBOX[-90,-180,90,180],"
+//		"    ID[\"EPSG\",4326]]";
+
+	return( true ); // return( Create(4326) );
 }
 
 //---------------------------------------------------------
@@ -980,7 +1045,7 @@ bool CSG_Projections::Get_Preference(CSG_Projection &Projection, const CSG_Strin
 {
 	int i = Authority_Code.Find(':');
 
-	if( i > 1 && i < Authority_Code.Length() - 2 )
+	if( i > 1 && i < (int)Authority_Code.Length() - 2 )
 	{
 		int Code; CSG_String Authority(Authority_Code.BeforeFirst(':'));
 
@@ -1084,7 +1149,7 @@ CSG_String CSG_Projections::Parse(const CSG_String &Definition, ESG_CRS_Format F
 }
 
 //---------------------------------------------------------
-bool CSG_Projections::Parse(const CSG_String &Definition, CSG_String *WKT1, CSG_String *WKT2, CSG_String *PROJ, CSG_String *ESRI)
+bool CSG_Projections::Parse(const CSG_String &Definition, CSG_String *PROJ, CSG_String *WKT2, CSG_String *WKT1, CSG_String *JSON, CSG_String *ESRI)
 {
 	if( Definition.is_Empty() )
 	{
@@ -1100,13 +1165,17 @@ bool CSG_Projections::Parse(const CSG_String &Definition, CSG_String *WKT1, CSG_
 		pTool->Set_Parameter("DEFINITION", Definition);
 		pTool->Set_Parameter("MULTILINE" , false);
 		pTool->Set_Parameter("SIMPLIFIED", false);
+		pTool->Set_Parameter("FORMAT"    , WKT1 || ESRI || JSON ? 5 : 6); // all : PROJ + WKT-2
 
 		SG_UI_ProgressAndMsg_Lock(true);
 
-		if( PROJ ) { pTool->Set_Parameter("FORMAT", 0); pTool->Execute(); *PROJ = pTool->Get_Parameter("PROJ")->asString(); }
-		if( WKT1 ) { pTool->Set_Parameter("FORMAT", 1); pTool->Execute(); *WKT1 = pTool->Get_Parameter("WKT1")->asString(); }
-		if( WKT2 ) { pTool->Set_Parameter("FORMAT", 2); pTool->Execute(); *WKT2 = pTool->Get_Parameter("WKT2")->asString(); }
-		if( ESRI ) { pTool->Set_Parameter("FORMAT", 4); pTool->Execute(); *ESRI = pTool->Get_Parameter("ESRI")->asString(); }
+		if( pTool->Execute() )
+		{
+			if( PROJ ) { *PROJ = pTool->Get_Parameter("PROJ")->asString(); }
+			if( WKT1 ) { *WKT1 = pTool->Get_Parameter("WKT1")->asString(); }
+			if( WKT2 ) { *WKT2 = pTool->Get_Parameter("WKT2")->asString(); }
+			if( ESRI ) { *ESRI = pTool->Get_Parameter("ESRI")->asString(); }
+		}
 
 		SG_UI_ProgressAndMsg_Lock(false);
 
@@ -1118,35 +1187,29 @@ bool CSG_Projections::Parse(const CSG_String &Definition, CSG_String *WKT1, CSG_
 	//-----------------------------------------------------
 	else // proj.lib parser not available ...fallback!
 	{
-		if( Definition.Find("+proj") == 0 )
-		{
-			CSG_String WKT;
+		int Code = -1; CSG_String Authority(Definition.BeforeFirst(':'));
 
-			if( gSG_Projections._WKT1_from_Proj4(WKT, Definition) )
+		if( Authority.is_Empty() || Definition.AfterFirst(':').asInt(Code) == false )
+		{
+			CSG_MetaData WKT(CSG_Projections::_WKT1_to_MetaData(Definition));
+
+			WKT.Get_Property("authority_name", Authority);
+			WKT.Get_Property("authority_code", Code);
+		}
+
+		if( !Authority.is_Empty() && Code > 0 )
+		{
+			CSG_Projection Projection;
+
+			if( gSG_Projections.Get_Projection(Projection, Code, Authority) )
 			{
-				if( WKT1 ) { *WKT1 = WKT       ; }
-				if( PROJ ) { *PROJ = Definition; }
+				if( WKT1 ) { *WKT1 = Projection.Get_WKT1(); }
+				if( WKT2 ) { *WKT2 = Projection.Get_WKT2(); }
+				if( PROJ ) { *PROJ = Projection.Get_PROJ(); }
+				if( ESRI ) { *ESRI = Projection.Get_ESRI(); }
 
 				return( true );
 			}
-
-			return( false );
-		}
-
-		//-------------------------------------------------
-		CSG_MetaData WKT(CSG_Projections::_WKT1_to_MetaData(Definition));
-
-		int Code; CSG_String Authority; CSG_Projection Projection;
-
-		if(	WKT.Get_Property("authority_name", Authority) && WKT.Get_Property("authority_code", Code)
-		&&  gSG_Projections.Get_Projection(Projection, Code, Authority) )
-		{
-			if( WKT1 ) { *WKT1 = Projection.Get_WKT1(); }
-			if( WKT2 ) { *WKT2 = Projection.Get_WKT2(); }
-			if( PROJ ) { *PROJ = Projection.Get_PROJ(); }
-			if( ESRI ) { *ESRI = Projection.Get_ESRI(); }
-
-			return( true );
 		}
 
 		//-------------------------------------------------
@@ -1157,21 +1220,18 @@ bool CSG_Projections::Parse(const CSG_String &Definition, CSG_String *WKT1, CSG_
 			if( WKT1 ) { *WKT1 = Definition; }
 			if( PROJ ) { *PROJ = Proj4     ; }
 
-			return( true );
+			return( !WKT2 || !ESRI );
 		}
 
 		//-------------------------------------------------
-		Authority = Definition.BeforeFirst(':');
+		CSG_String WKT;
 
-		if( !Authority.is_Empty() && Definition.AfterFirst(':').asInt(Code)
-		&&  gSG_Projections.Get_Projection(Projection, Code, Authority) )
+		if( gSG_Projections._WKT1_from_Proj4(WKT, Definition) )
 		{
-			if( WKT1 ) { *WKT1 = Projection.Get_WKT1(); }
-			if( WKT2 ) { *WKT2 = Projection.Get_WKT2(); }
-			if( PROJ ) { *PROJ = Projection.Get_PROJ(); }
-			if( ESRI ) { *ESRI = Projection.Get_ESRI(); }
+			if( WKT1 ) { *WKT1 = WKT       ; }
+			if( PROJ ) { *PROJ = Definition; }
 
-			return( true );
+			return( !WKT2 || !ESRI );
 		}
 	}
 
@@ -1273,7 +1333,7 @@ bool CSG_Projections::_WKT2_to_MetaData(CSG_MetaData &MetaData, const CSG_String
 
 	int Colon = -1, Bracket = -1;
 
-	for(int i=0, bracket=0, quota=0; Colon<0 && i<WKT.Length(); i++)
+	for(int i=0, bracket=0, quota=0; Colon<0 && i<(int)WKT.Length(); i++)
 	{
 		switch( WKT[i] )
 		{
@@ -1367,7 +1427,14 @@ CSG_MetaData CSG_Projections::_WKT2_to_MetaData(const CSG_String &WKT, bool bTri
 //---------------------------------------------------------
 CSG_String CSG_Projections::Convert_WKT2_to_XML(const CSG_String &WKT)
 {
-	return( _WKT2_to_MetaData(WKT, false).asText(1) );
+	CSG_String XML;
+
+	if( !WKT.is_Empty() )
+	{
+		XML = _WKT2_to_MetaData(WKT, false).asText(1);
+	}
+	
+	return( XML );
 }
 
 
@@ -2151,8 +2218,7 @@ ESG_CRS_Type CSG_Projections::Get_CRS_Type(const CSG_String &Identifier)
 	if( !Identifier.CmpNoCase("PROJCS") || !Identifier.CmpNoCase("PROJCRS") ) { return( ESG_CRS_Type::Projection ); }
 	if( !Identifier.CmpNoCase("GEOGCS") || !Identifier.CmpNoCase("GEOGCRS") ) { return( ESG_CRS_Type::Geographic ); }
 	if( !Identifier.CmpNoCase("GEOCCS") || !Identifier.CmpNoCase("GEOCCRS") ) { return( ESG_CRS_Type::Geocentric ); }
-	if( !Identifier.CmpNoCase("GEODCS") || !Identifier.CmpNoCase("GEODCRS") ) { return( ESG_CRS_Type::Geographic ); }
-//	if( !Identifier.CmpNoCase("GEODCS") || !Identifier.CmpNoCase("GEODCRS") ) { return( ESG_CRS_Type::Geodetic   ); }
+	if( !Identifier.CmpNoCase("GEODCS") || !Identifier.CmpNoCase("GEODCRS") ) { return( ESG_CRS_Type::Geodetic   ); }
 
 	return( ESG_CRS_Type::Undefined );
 }
@@ -2179,7 +2245,7 @@ CSG_String CSG_Projections::Get_CRS_Type_Name(ESG_CRS_Type Type)
 	case ESG_CRS_Type::Geographic: return( _TL("Geographic Coordinate System") );
 	case ESG_CRS_Type::Geocentric: return( _TL("Geocentric Coordinate System") );
 	case ESG_CRS_Type::Geodetic  : return( _TL("Geodetic Coordinate System"  ) );
-	default                      : return( _TL("Undefined Coordinate System" ) );
+	default                      : return( _TL("Unknown Coordinate System"   ) );
 	}
 }
 
@@ -2646,10 +2712,11 @@ bool	SG_Get_Projected	(CSG_Shapes *pSource, CSG_Shapes *pTarget, const CSG_Proje
 			CSG_Data_Manager Data; Data.Add(pSource); pTool->Set_Manager(&Data);
 
 			pTool->Set_Callback(false);
-			pTool->Set_Parameter("SOURCE"    , pSource);
-			pTool->Set_Parameter("CRS_STRING", Target.Get_WKT());
-			pTool->Set_Parameter("COPY"      , false);
-			pTool->Set_Parameter("PARALLEL"  , true);
+			pTool->Set_Parameter("CRS_WKT" , Target.Get_WKT2());
+			pTool->Set_Parameter("CRS_PROJ", Target.Get_PROJ());
+			pTool->Set_Parameter("SOURCE"  , pSource);
+			pTool->Set_Parameter("COPY"    , false);
+			pTool->Set_Parameter("PARALLEL", true);
 
 			SG_UI_ProgressAndMsg_Lock(true);
 			bool bResult = pTool->Execute();
